package cn.ibizlab.ehr.webapi.dto;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.math.BigInteger;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.alibaba.fastjson.annotation.JSONField;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import cn.ibizlab.ehr.util.domain.DTOBase;
import cn.ibizlab.ehr.util.domain.DTOClient;
import lombok.Data;

/**
 * 服务DTO对象[PimPatentDTO]
 */
@Data
public class PimPatentDTO extends DTOBase implements Serializable {

	private static final long serialVersionUID = 1L;

    /**
     * 属性 [ZLH]
     *
     */
    @JSONField(name = "zlh")
    @JsonProperty("zlh")
    @NotBlank(message = "[专利号(*)]不允许为空!")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String zlh;

    /**
     * 属性 [UPDATEDATE]
     *
     */
    @JsonFormat(pattern="yyyy-MM-dd HH:mm:ss", locale = "zh" , timezone="GMT+8")
    @JSONField(name = "updatedate" , format="yyyy-MM-dd HH:mm:ss")
    @JsonProperty("updatedate")
    private Timestamp updatedate;

    /**
     * 属性 [PIMPATENTID]
     *
     */
    @JSONField(name = "pimpatentid")
    @JsonProperty("pimpatentid")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String pimpatentid;

    /**
     * 属性 [ORGID]
     *
     */
    @JSONField(name = "orgid")
    @JsonProperty("orgid")
    @Size(min = 0, max = 200, message = "内容长度必须小于等于[200]")
    private String orgid;

    /**
     * 属性 [JLSS]
     *
     */
    @JSONField(name = "jlss")
    @JsonProperty("jlss")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String jlss;

    /**
     * 属性 [ORGSECTORID]
     *
     */
    @JSONField(name = "orgsectorid")
    @JsonProperty("orgsectorid")
    @Size(min = 0, max = 200, message = "内容长度必须小于等于[200]")
    private String orgsectorid;

    /**
     * 属性 [ZLHQSJ]
     *
     */
    @JsonFormat(pattern="yyyy-MM-dd", locale = "zh" , timezone="GMT+8")
    @JSONField(name = "zlhqsj" , format="yyyy-MM-dd")
    @JsonProperty("zlhqsj")
    @NotNull(message = "[专利获取时间(*)]不允许为空!")
    private Timestamp zlhqsj;

    /**
     * 属性 [JLSPZT]
     *
     */
    @JSONField(name = "jlspzt")
    @JsonProperty("jlspzt")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String jlspzt;

    /**
     * 属性 [JLCZZ]
     *
     */
    @JSONField(name = "jlczz")
    @JsonProperty("jlczz")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String jlczz;

    /**
     * 属性 [ENABLE]
     *
     */
    @JSONField(name = "enable")
    @JsonProperty("enable")
    private Integer enable;

    /**
     * 属性 [PIMPATENTNAME]
     *
     */
    @JSONField(name = "pimpatentname")
    @JsonProperty("pimpatentname")
    @NotBlank(message = "[专利名称(*)]不允许为空!")
    @Size(min = 0, max = 200, message = "内容长度必须小于等于[200]")
    private String pimpatentname;

    /**
     * 属性 [UPDATEMAN]
     *
     */
    @JSONField(name = "updateman")
    @JsonProperty("updateman")
    @Size(min = 0, max = 60, message = "内容长度必须小于等于[60]")
    private String updateman;

    /**
     * 属性 [JLGLBH]
     *
     */
    @JSONField(name = "jlglbh")
    @JsonProperty("jlglbh")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String jlglbh;

    /**
     * 属性 [REASON]
     *
     */
    @JSONField(name = "reason")
    @JsonProperty("reason")
    @Size(min = 0, max = 500, message = "内容长度必须小于等于[500]")
    private String reason;

    /**
     * 属性 [CREATEMAN]
     *
     */
    @JSONField(name = "createman")
    @JsonProperty("createman")
    @Size(min = 0, max = 60, message = "内容长度必须小于等于[60]")
    private String createman;

    /**
     * 属性 [ENCLOLURE]
     *
     */
    @JSONField(name = "enclolure")
    @JsonProperty("enclolure")
    @Size(min = 0, max = 2000, message = "内容长度必须小于等于[2000]")
    private String enclolure;

    /**
     * 属性 [CREATEDATE]
     *
     */
    @JsonFormat(pattern="yyyy-MM-dd HH:mm:ss", locale = "zh" , timezone="GMT+8")
    @JSONField(name = "createdate" , format="yyyy-MM-dd HH:mm:ss")
    @JsonProperty("createdate")
    private Timestamp createdate;

    /**
     * 属性 [ZLPZGB]
     *
     */
    @JSONField(name = "zlpzgb")
    @JsonProperty("zlpzgb")
    @NotBlank(message = "[专利批准国别(*)]不允许为空!")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String zlpzgb;

    /**
     * 属性 [PIMPERSONNAME]
     *
     */
    @JSONField(name = "pimpersonname")
    @JsonProperty("pimpersonname")
    @Size(min = 0, max = 200, message = "内容长度必须小于等于[200]")
    private String pimpersonname;

    /**
     * 属性 [YGBH]
     *
     */
    @JSONField(name = "ygbh")
    @JsonProperty("ygbh")
    @Size(min = 0, max = 200, message = "内容长度必须小于等于[200]")
    private String ygbh;

    /**
     * 属性 [ORMORGSECTORID]
     *
     */
    @JSONField(name = "ormorgsectorid")
    @JsonProperty("ormorgsectorid")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String ormorgsectorid;

    /**
     * 属性 [ORMORGID]
     *
     */
    @JSONField(name = "ormorgid")
    @JsonProperty("ormorgid")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String ormorgid;

    /**
     * 属性 [PIMPERSONID]
     *
     */
    @JSONField(name = "pimpersonid")
    @JsonProperty("pimpersonid")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String pimpersonid;


    /**
     * 设置 [ZLH]
     */
    public void setZlh(String  zlh){
        this.zlh = zlh ;
        this.modify("zlh",zlh);
    }

    /**
     * 设置 [JLSS]
     */
    public void setJlss(String  jlss){
        this.jlss = jlss ;
        this.modify("jlss",jlss);
    }

    /**
     * 设置 [ZLHQSJ]
     */
    public void setZlhqsj(Timestamp  zlhqsj){
        this.zlhqsj = zlhqsj ;
        this.modify("zlhqsj",zlhqsj);
    }

    /**
     * 设置 [JLSPZT]
     */
    public void setJlspzt(String  jlspzt){
        this.jlspzt = jlspzt ;
        this.modify("jlspzt",jlspzt);
    }

    /**
     * 设置 [JLCZZ]
     */
    public void setJlczz(String  jlczz){
        this.jlczz = jlczz ;
        this.modify("jlczz",jlczz);
    }

    /**
     * 设置 [PIMPATENTNAME]
     */
    public void setPimpatentname(String  pimpatentname){
        this.pimpatentname = pimpatentname ;
        this.modify("pimpatentname",pimpatentname);
    }

    /**
     * 设置 [JLGLBH]
     */
    public void setJlglbh(String  jlglbh){
        this.jlglbh = jlglbh ;
        this.modify("jlglbh",jlglbh);
    }

    /**
     * 设置 [REASON]
     */
    public void setReason(String  reason){
        this.reason = reason ;
        this.modify("reason",reason);
    }

    /**
     * 设置 [ENCLOLURE]
     */
    public void setEnclolure(String  enclolure){
        this.enclolure = enclolure ;
        this.modify("enclolure",enclolure);
    }

    /**
     * 设置 [ZLPZGB]
     */
    public void setZlpzgb(String  zlpzgb){
        this.zlpzgb = zlpzgb ;
        this.modify("zlpzgb",zlpzgb);
    }

    /**
     * 设置 [PIMPERSONID]
     */
    public void setPimpersonid(String  pimpersonid){
        this.pimpersonid = pimpersonid ;
        this.modify("pimpersonid",pimpersonid);
    }


}


